C Calculates the angle between two reciprocal lattice vectors
C and also the magnitudes of these vectors for a given pair of
C Miller indices, lattice type and systematic absences. These 
C calculations are compared against given data within a specified
C level of accuracy.
C
C ACCU is the specified fractional accuracy, typically 0.03
C F is the metric tensor which converts vectors from a 
C   reciprocal to real basis
C GV1 and GV2 are the measured d-spacings 
C AA is the measured angle between the two vectors whose d-spacings
C   are GV1 and GV2 respectively.
C If J40 is set to zero, then the d-spacings GV1 and GV2 are not 
C   needed as inputs; instead the ratio RR between the two reciprocal
C   lattice vectors can be input. This is useful when the camera
C   constant is not known in an electron diffraction experiment.
C H K L and HH KK LL are the guessed Miller indices of the two
C   reciprocal lattice vectors
C JTYPE is the lattice type, and JLOG, JLOG2 determine whether
C   the reciprocal lattice vector is a systematic absence
C

      SUBROUTINE MAP_CRYSTAL_TEST1(ACCU,F,GV1,GV2,RR,AA,
     &H,K,L,HH,KK,LL,JTYPE,AD,BD,U1,V1,W1,AX,PI)
      IMPLICIT NONE
C
C
      REAL ACCU,F(9),GV1,GV2,RR,AA,H,K,L,HH,KK,LL,AD,BD,U1,V1,
     &W1,A,B,DUM1,DUM2,DUM3,DUM4,R,C,ANGLE,AX,
     &H1,K1,L1,HH1,KK1,LL1,PI,AA2,MAP_UTIL_MAG
      INTEGER JTYPE,JLOG,JLOG2
C
      IF(JTYPE .EQ. 1)GOTO 6
         CALL MAP_CRYSTAL_TYPE(H,K,L,JTYPE,JLOG)
         CALL MAP_CRYSTAL_TYPE(HH,KK,LL,JTYPE,JLOG2)
      IF(JLOG .EQ. 1 .OR. JLOG2 .EQ. 1)GOTO 2
C
C Calculate the d-spacings AD and BD for H K L and HH KK LL respectively
6        CALL MAP_UTIL_TRANS(F,H,K,L,H1,K1,L1)
           A=MAP_UTIL_MAG(H,K,L,H1,K1,L1)
           A=SQRT(A)
           AD=1.0/A
C
         CALL MAP_UTIL_TRANS(F,HH,KK,LL,HH1,KK1,LL1)
           B=MAP_UTIL_MAG(HH,KK,LL,HH1,KK1,LL1)
           B=SQRT(B)
           BD=1.0/B
C
C Check whether calculated spacings agree with those input within
C   the limits of specified accuracy
           DUM1=ABS((BD/GV1)-1.0)
           DUM2=ABS((AD/GV1)-1.0)
           DUM3=ABS((BD/GV2)-1.0)
           DUM4=ABS((AD/GV2)-1.0)
      IF(DUM3 .LT. ACCU .OR. DUM4 .LT. ACCU) GOTO 4
           GOTO 2
4     IF (DUM1 .LT. ACCU .OR. DUM2 .LT. ACCU) GOTO 5
           GOTO 2
C
C Check whether ratio of vector magnitudes is within specified error
5          R=A/B
      IF(R .GE. 1.0) GOTO 1
           R=B/A
1     IF(ABS((RR/R)-1.0) .GE. ACCU) GOTO 2
C
C Calculate the angle and compare with measured angle with error
           C=MAP_UTIL_MAG(H,K,L,HH1,KK1,LL1)
           ANGLE=C/(A*B)
           AA2=COS(AA)
      IF(ABS(ABS(ANGLE)-AA2)  .GE. ACCU) GOTO 2
C
C Find the zone axis and normalise its components using Weiss Zone Rule
           U1=K*LL-L*KK
           V1=L*HH-H*LL
           W1=H*KK-K*HH
           CALL MAP_UTIL_NORM(U1,V1,W1)
C
        AX=ACOS(ANGLE)*180.0/PI
C
C
C
C
2       RETURN
        END
